## Version 1.0.0 (2023-07-24)
### 🎉 New features

- upgrade CW to version 4
  *BREAKING CHANGE*: upgrade CW to version 4

## Version 0.14.0 (2023-05-04)
### 🎉 New features

- upgrade cubicweb to ">=3.38.0,<3.39.0"

### 👷 Bug fixes

- hooks: recompute progress when budget changes

### 🤖 Continuous integration

- fix bad stage name
- gitlab-ci: use templates from a common repository
- that tox option is now named allowlist_externals

## Version 0.13.1 (2021-06-07)
### 👷 Bug fixes

- MANIFEST: include changelog

### 🤖 Continuous integration

- add deb packages

## Version 0.13.0 (2021-06-07)
### 🎉 New features

- WorkOrder: make budget required and positive

### 📝 Documentation

- licence: update licence dates

### 🤖 Continuous integration

- use gitlab-ci templates